@@ -143,11 +143,11 @@ class Client:
 
             historical_stats = await resp.json()
 
-        case_history = []
-        death_history = []
-        recovery_history = []
+        case_history = {}
+        death_history = {}
+        recovery_history = {}
                 
-        name = historical_stats["country"]
+        name = historical_stats["country"].title()
 
         if not historical_stats["timeline"]["cases"]:
             raise APIerror('Couldn\'t get stats for given country')
